==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-CO/mail.php <==
<?php

return array(
    'a_user_canceled' => 'El usuario ha cancelado el item solicitado en la pagina Web',
    'a_user_requested' => 'Un usuario a solicitado un item en la pagina Web',
    'accessory_name' => 'Nombre de accesorio:',
    'additional_notes' => 'Notas adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en la web :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre del activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Etiqueta de activo:',
    'assigned_to' => 'Asignado a',
    'best_regards' => 'Cordialmente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de entrada:',
    'checkout_date' => 'Fecha de salida:',
    'click_to_confirm' => 'Por favor, pulsa en el siguiente enlace para verificar tu cuenta de :web:',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Cantidad actual',
    'Days' => 'Días',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha de devolución prevista:',
    'expires' => 'Expira',
    'Expiring_Assets_Report' => 'Informe de activos que expiran.',
    'Expiring_Licenses_Report' => 'Informe de licencias que expiran.',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'Ha leído y aceptado los términos de uso y he recibido este artículo.',
    'item' => 'Articulo:',
    'Item_Request_Canceled' => 'Solicitud de cancelación de requerimiento',
    'Item_Requested' => 'Artículo solicitado',
    'link_to_update_password' => 'Haga clic en el siguiente enlace para actualizar su: contraseña de la web:',
    'login_first_admin' => 'Inicie sesión en su nueva instalación de Snipe-IT con las credenciales siguientes:',
    'login' => 'Entrar:',
    'Low_Inventory_Report' => 'Reporte de inventario bajo',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo se ha extraído bajo su nombre, los detalles están a continuación.',
    'password' => 'Contraseña:',
    'password_reset' => 'Reiniciar la contraseña',

    'read_the_terms' => 'Por favor lea las condiciones de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor lea los términos de uso abajo y haga clic en el enlace en la parte inferior para confirmar que leído y acepta los términos de uso y han recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Tu enlace de restablecimiento de contraseña',
    'reset_password' => 'Haga Clic aquí para restablecer su contraseña:',
    'serial' => 'Número de serie',
    'supplier' => 'Proveedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos de Snipe-IT. Si tienes esto, correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'low_inventory_alert' => 'Hay :count elemento que está por debajo del inventario mínimo o que pronto estará debajo.|Hay :count elementos que están por debajo del inventario mínimo o que pronto serán bajos.',
    'assets_warrantee_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Usuario',
    'username' => 'Nombre de usuario',
    'welcome' => 'Bienvenido, :name',
    'welcome_to' => '¡Bienvenido a: web!',
    'your_credentials' => 'Tus credenciales de Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesorio devuelto',
    'Asset_Checkin_Notification' => 'Activo devuelto',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Date' => 'Un activo asignado a ti debe ser devuelto en :date',
    'your_assets' => 'Ver tus activos'
);

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/es-CO/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Un usuario ha aceptado un artículo',
    'acceptance_asset_declined' => 'Un usuario ha rechazado un artículo',
    'a_user_canceled' => 'El usuario ha cancelado el item solicitado en la pagina Web',
    'a_user_requested' => 'Un usuario a solicitado un item en la pagina Web',
    'accessory_name' => 'Nombre de accesorio:',
    'additional_notes' => 'Notas adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para usted en el sitio :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre del activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Etiqueta de equipo',
    'assigned_to' => 'Asignado a',
    'best_regards' => 'Saludos cordiales,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de entrada:',
    'checkout_date' => 'Fecha de salida:',
    'click_to_confirm' => 'Por favor, haga clic en el siguiente enlace para confirmar su cuenta :web:',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'Confirm_Asset_Checkin' => 'Confirmación de devolución de activo',
    'Confirm_Accessory_Checkin' => 'Confirmación de registro de accesorio',
    'Confirm_accessory_delivery' => 'Confirmación de entrega del accesorio',
    'Confirm_license_delivery' => 'Confirmación de entrega de la licencia',
    'Confirm_asset_delivery' => 'Confirmación de entrega del activo',
    'Confirm_consumable_delivery' => 'Confirmación de entrega del consumible',
    'current_QTY' => 'Cantidad actual',
    'Days' => 'Dias',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Fecha de devolución prevista:',
    'expires' => 'Caduca',
    'Expiring_Assets_Report' => 'Informe de activos caducados.',
    'Expiring_Licenses_Report' => 'Informe de licencias caducando.',
    'hello' => 'Hola',
    'hi' => 'Hi',
    'i_have_read' => 'Ha leído y aceptado los términos de uso y he recibido este artículo.',
    'item' => 'Articulo:',
    'Item_Request_Canceled' => 'Solicitud de cancelación de requerimiento',
    'Item_Requested' => 'Artículo solicitado',
    'link_to_update_password' => 'Haga clic en el siguiente enlace para actualizar su: contraseña de la web:',
    'login_first_admin' => 'Inicie sesión en su nueva instalación de Snipe-IT con las credenciales siguientes:',
    'login' => 'Entrar:',
    'Low_Inventory_Report' => 'Baja informe de inventario',
    'inventory_report' => 'Informe de inventario',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo se ha extraído bajo su nombre, los detalles están a continuación.',
    'password' => 'Contraseña:',
    'password_reset' => 'Reiniciar la contraseña',

    'read_the_terms' => 'Por favor, lea los términos de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor lea los términos de uso abajo y haga clic en el enlace en la parte inferior para confirmar que leído y acepta los términos de uso y han recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Enlace de restablecimiento de contraseña',
    'reset_password' => 'Haga Clic aquí para restablecer su contraseña:',
    'serial' => 'Número de serie',
    'supplier' => 'Proveedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos de Snipe-IT. Si tienes esto, correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'low_inventory_alert' => 'Hay :count elemento que está por debajo del inventario mínimo o que pronto estará debajo.|Hay :count elementos que están por debajo del inventario mínimo o que pronto serán bajos.',
    'assets_warrantee_alert' => 'Hay :count activo con una garantía que expira en los próximos :threshold days.|Hay :count activos con garantías que expiran en los siguientes :threshold days.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Hay :count activo que se está preparando para auditoría dentro de :threshold days.|Hay :count activos que se están preparando para auditoría en :threshold days.',
    'user' => 'Usuario',
    'username' => 'Nombre de usuario',
    'welcome' => 'Bienvenido, :name',
    'welcome_to' => '¡Bienvenido a: web!',
    'your_credentials' => 'Tus credenciales de Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesorio devuelto',
    'Asset_Checkin_Notification' => 'Activo devuelto',
    'Asset_Checkout_Notification' => 'Recurso reservado',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'Expected_Checkin_Report' => 'Informe de devolución de activo esperado',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Date' => 'Un activo asignado a ti debe ser devuelto en :date',
    'your_assets' => 'Ver tus activos',
    'rights_reserved' => 'Todos los derechos reservados.',
];
